import { Column } from 'react-table';
import { StatusCellColor } from '../../../index';
export interface ShippingAddress {
    receiverName: string;
    receiverInstitution: string;
    addressLineOne: string;
    addressLineTwo?: string;
    country: string;
    state?: string;
    city: string;
    zipCode: string;
    telephone: string;
    email: string;
    comments?: string;
}
export interface TeamStatuses {
    name: TeamStatus;
    payment: TeamStatus;
    principalConsentForm?: TeamStatus;
    piConsentForm?: TeamStatus;
    shippingAddress: TeamStatus;
}
export interface Team {
    uuid: string;
    primaryHostInstitution: {
        uuid: string;
        shortName: string;
        status: string;
        kind: string;
        address: string;
        country: string;
        website: string;
        city: string;
        region: string;
        subRegion: string;
    };
    name: string;
    level: TeamLevel;
    status: TeamStatus;
    kind: TeamKind;
    competitionUuid: string;
    shippingAddress: ShippingAddress;
    statuses: TeamStatuses;
}
export declare const getTeamStatusColor: (status: TeamStatus) => StatusCellColor;
export declare const teamTableColumns: ReadonlyArray<Column<any>>;
export declare enum TeamKind {
    HIGH_SCHOOL = "high-school",
    COLLEGIATE = "collegiate",
    COMMERCIAL = "commercial",
    COMMUNITY_LAB = "community-lab"
}
export declare enum TeamLevel {
    UNDERGRAD = "undergrad",
    OVERGRAD = "overgrad",
    HIGH_SCHOOL = "high-school"
}
export declare enum TeamStatus {
    PENDING = "pending",
    ACCEPTED = "accepted",
    WITHDRAWN = "withdrawn",
    DISQUALIFIED = "disqualified",
    REJECTED = "rejected"
}
export declare const mapTeamLevelToLabel: (level: TeamLevel) => string;
export declare const getHostInstitutionKindLabel: (kind: string) => string | undefined;
